xarrera
=============

Schema validation for `Xarray`_ objects

.. _xarray: https://xarray.dev

.. warning::

   This package is experimental, and new versions might introduce backwards incompatible
   changes.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started:

   installation
   quickstart

.. toctree::
   :maxdepth: 1
   :caption: Help & Reference:

   api
